<?php
$lang['expired_searchable'] = 'Artikel, deren Anzeigedauer &uuml;berschritten ist, d&uuml;rfen in den Suchergebnissen erscheinen';
$lang['helpshowall'] = 'Alle Artikel anzeigen (unabh&auml;ngig von deren Anzeigedauer)';
$lang['error_invaliddates'] = 'Ein oder mehrere der eingegebenen Daten sind ung&uuml;ltig';
$lang['notify_n_draft_items_sub'] = '%d News-Artikel';
$lang['notify_n_draft_items'] = '%s News-Artikel wurde(n) noch nicht ver&ouml;ffentlicht.';
$lang['unlimited'] = 'Unbegrenzt';
$lang['none'] = 'Keine';
$lang['anonymous'] = 'Anonym';
$lang['unknown'] = 'Unbekannt';
$lang['fesubmit_redirect'] = 'Die Seiten-ID oder der Seiten-Alias der Seite, auf die der Einsender eines Artikels &uuml;ber die fesubmit-Aktion weitergeleitet werden soll';
$lang['allow_summary_wysiwyg'] = 'Den WYSIWYG-Editor f&uuml;r das Zusammenfassungsfeld verwenden';
$lang['title_browsecat_template'] = 'Vorlageneditor f&uuml;r die Kategorien-Anzeige';
$lang['title_browsecat_sysdefault'] = 'Voreingestelltes Template f&uuml;r die Kategorien-Anzeige';
$lang['browsecattemplate'] = 'Vorlagen f&uuml;r die Kategorien-Anzeige';
$lang['error_filesize'] = 'Die hochgeladene Datei &uuml;berschreitet die maximal erlaubte Gr&ouml;&szlig;e';
$lang['post_date_desc'] = 'nach Erstellungsdatum absteigend';
$lang['post_date_asc'] = 'nach Erstellungsdatum aufsteigend';
$lang['expiry_date_desc'] = 'nach Verfallsdatum absteigend';
$lang['expiry_date_asc'] = 'nach Verfallsdatum aufsteigend';
$lang['title_desc'] = 'nach Titel absteigend';
$lang['title_asc'] = 'nach Titel aufsteigend';
$lang['fesubmit_status'] = 'Der Status f&uuml;r Artikel, die &uuml;ber die Webseite (Frontend) erstellt wurden';
$lang['error_invalidfiletype'] = 'Dieser Dateityp darf nicht hochgeladen werden';
$lang['error_upload'] = 'Beim Hochladen der Datei ist ein Problem aufgetreten';
$lang['error_movefile'] = 'Konnte die Datei %s nicht erstellen';
$lang['error_mkdir'] = 'Konnte das Verzeichnis %s nicht erstellen';
$lang['expiry_interval'] = 'Voreingestellte Anzahl der Tage, nach denen ein Artikel nicht mehr auf der Webseite angezeigt werden soll (falls die Zeitsteuerung verwendet wird)';
$lang['removed'] = 'Entfernt';
$lang['msg_contenttype_removed'] = 'Der Inhaltstyp &bdquo;News&ldquo; wird nicht mehr unterst&uuml;tzt. Bitte verwenden Sie in Ihren Seiten-Templates bzw. -inhalten anstatt dessen den {news}-Tag mit den entsprechenden Parametern.';
$lang['delete_selected'] = 'Ausgew&auml;hlte Artikel l&ouml;schen';
$lang['areyousure_deletemultiple'] = 'Wollen Sie wirklich alle ausgew&auml;hlten Artikel l&ouml;schen?\nDies kann NICHT r&uuml;ckg&auml;ngig gemacht werden!';
$lang['error_templatenamexists'] = 'Es existiert bereits ein Template mit diesem Namen!';
$lang['error_noarticlesselected'] = 'Es wurden keine Artikel ausgew&auml;hlt';
$lang['reassign_category'] = 'Kategorie &auml;ndern auf';
$lang['select'] = 'Ausw&auml;hlen';
$lang['approve'] = 'Status auf &bdquo;ver&ouml;ffentlicht&ldquo; setzen';
$lang['revert'] = 'Status auf &bdquo;Entwurf&ldquo; setzen';
$lang['hide_summary_field'] = 'Das Zusammenfassungsfeld verbergen, wenn ein Artikel hinzugef&uuml;gt oder bearbeitet wird';
$lang['textbox'] = 'Einzeiliges Textfeld';
$lang['checkbox'] = 'Kontrollk&auml;stchen';
$lang['textarea'] = 'Mehrzeiliger Textbereich';
$lang['file'] = 'Datei';
$lang['auto_create_thumbnails'] = 'F&uuml;r Dateien mit dieser Namenserweiterung automatisch ein Vorschaubild erstellen';
$lang['allowed_upload_types'] = 'Nur Dateien mit dieser Namenserweiterung d&uuml;rfen hochgeladen werden';
$lang['fielddefupdated'] = 'Das Extra-Feld wurde aktualisiert';
$lang['editfielddef'] = 'Extra-Feld bearbeiten';
$lang['up'] = 'Nach oben';
$lang['down'] = 'Nach unten';
$lang['fielddefdeleted'] = 'Extra-Feld gel&ouml;scht';
$lang['nameexists'] = 'Ein Extra-Feld mit diesem Namen existiert bereits';
$lang['notanumber'] = 'Die maximale L&auml;nge ist keine Zahl';
$lang['fielddef'] = 'Extra-Feld';
$lang['fielddefadded'] = 'Das Extra-Feld wurde erfolgreich hinzugef&uuml;gt';
$lang['public'] = '&Ouml;ffentlich';
$lang['type'] = 'Typ';
$lang['info_maxlength'] = 'Die maximale L&auml;nge hat nur Auswirkungen auf einzeilige Textfelder.';
$lang['maxlength'] = 'Maximale L&auml;nge';
$lang['addfielddef'] = 'Extra-Feld hinzuf&uuml;gen';
$lang['customfields'] = 'Extra-Felder';
$lang['deprecated'] = 'Nicht unterst&uuml;tzt';
$lang['subject_newnews'] = 'Ein neuer Artikel wurde ins System eingestellt';
$lang['email_subject'] = 'Betreff der ausgehenden Email';
$lang['email_template'] = 'Inhalt der Email-Nachricht';
$lang['formsubmit_emailaddress'] = 'Email-Adresse zur Benachrichtigung bei neuen Artikeln';
$lang['extra'] = 'Extra-Feld';
$lang['uploadscategory'] = 'Kategorie im Uploads-Modul';
$lang['title_available_templates'] = 'Verf&uuml;gbare Templates';
$lang['resettodefault'] = 'Auf die programmseitigen Voreinstellungen zur&uuml;cksetzen';
$lang['title_form_template'] = 'Editor f&uuml;r die Formular-Templates';
$lang['title_detail_template'] = 'Editor f&uuml;r die Detail-Templates';
$lang['title_summary_template'] = 'Editor f&uuml;r die Zusammenfassungs-Templates';
$lang['prompt_templatename'] = 'Template-Name';
$lang['prompt_template'] = 'Template-Quelle';
$lang['title_form_sysdefault'] = 'Standard-Template f&uuml;r das Formular';
$lang['title_summary_sysdefault'] = 'Standard-Template f&uuml;r die Zusammenfassung';
$lang['title_detail_sysdefault'] = 'Standard-Template f&uuml;r die Details';
$lang['info_sysdefault2'] = '<strong>Hinweis:</strong> In den Textbereichen dieser Registerkarte k&ouml;nnen Sie die Templates vordefinieren, die automatisch eingef&uuml;gt werden, wenn Sie eine neues Zusammenfassungs-, Detail- oder Formular-Template erstellen. Das &Auml;ndern/Speichern der Inhalte in diesem Reiter hat <strong>keine Auswirkungen auf die aktuelle Anzeige</strong>.';
$lang['info_sysdefault'] = '<em>(der Inhalt, der standardm&auml;&szlig;ig beim Erstellen eines neuen Templates verwendet wird)</em>';
$lang['template'] = 'Template ';
$lang['prompt_name'] = 'Name ';
$lang['prompt_default'] = 'Standard';
$lang['prompt_newtemplate'] = 'Ein neues Template erstellen';
$lang['help_pagelimit'] = 'Maximale Anzahl der anzuzeigenden Eintr&auml;ge (pro Seite). Ohne diesen Parameter werden alle Eintr&auml;ge angezeigt. Wenn dieser Parameter gesetzt wurde und mehr Eintr&auml;ge vorhanden sind, als pro Seite angezeigt werden sollen, werden Links eingeblendet, um vorw&auml;rts oder r&uuml;ckw&auml;rts zu den n&auml;chsten Seiten bl&auml;ttern zu k&ouml;nnen.';
$lang['prompt_page'] = 'Seite';
$lang['firstpage'] = '&laquo;';
$lang['prevpage'] = '&lsaquo;';
$lang['nextpage'] = '&rsaquo;';
$lang['lastpage'] = '&raquo;';
$lang['prompt_of'] = 'von';
$lang['prompt_pagelimit'] = 'Artikel pro Seite';
$lang['prompt_sorting'] = 'Sortieren';
$lang['title_filter'] = 'Anzeige filtern';
$lang['published'] = 'Ver&ouml;ffentlicht';
$lang['draft'] = 'Entwurf';
$lang['expired'] = 'abgelaufen';
$lang['author'] = 'Autor';
$lang['sysdefaults'] = 'Auf die programmseitigen Voreinstellungen zur&uuml;cksetzen';
$lang['restoretodefaultsmsg'] = 'Diese Funktion setzt die Templates auf die programmseitigen Voreinstellung zur&uuml;ck. Wollen Sie das wirklich?';
$lang['addarticle'] = 'Artikel hinzuf&uuml;gen';
$lang['articleadded'] = 'Der Artikel wurde erfolgreich hinzugef&uuml;gt.';
$lang['articleupdated'] = 'Der Artikel wurde erfolgreich aktualisiert.';
$lang['articledeleted'] = 'Der Artikel wurde erfolgreich gel&ouml;scht.';
$lang['addcategory'] = 'Kategorie hinzuf&uuml;gen';
$lang['categoryadded'] = 'Die Kategorie wurde erfolgreich hinzugef&uuml;gt.';
$lang['categoryupdated'] = 'Die Kategorie wurde erfolgreich aktualisiert.';
$lang['categorydeleted'] = 'Die Kategorie wurde erfolgreich gel&ouml;scht.';
$lang['addnewsitem'] = 'News-Eintrag hinzuf&uuml;gen';
$lang['allcategories'] = 'Alle Kategorien';
$lang['allentries'] = 'Alle Eintr&auml;ge';
$lang['areyousure'] = 'Wollen Sie dies wirklich l&ouml;schen?';
$lang['articles'] = 'Artikel';
$lang['cancel'] = 'Abbrechen';
$lang['category'] = 'Kategorie';
$lang['categories'] = 'Kategorien';
$lang['default_category'] = 'Standard-Kategorie';
$lang['content'] = 'Inhalt';
$lang['dateformat'] = '%s hat kein g&uuml;ltiges JJJJ-MM-TT hh:mm:ss Format';
$lang['delete'] = 'L&ouml;schen';
$lang['description'] = 'Hinzuf&uuml;gen, Bearbeiten und L&ouml;schen von News-Artikeln';
$lang['formtemplate'] = 'Formular-Templates';
$lang['detailtemplate'] = 'Detail-Templates';
$lang['default_templates'] = 'Voreingestellte Templates';
$lang['detailtemplateupdated'] = 'Das aktualisierte Detail-Template wurde in der Datenbank gespeichert.';
$lang['displaytemplate'] = 'Template anzeigen';
$lang['edit'] = 'Bearbeiten';
$lang['enddate'] = 'Endzeitpunkt';
$lang['endrequiresstart'] = 'Wenn Sie einen Endzeitpunkt angeben, m&uuml;ssen Sie auch ein Startzeitpunkt festgelegen.';
$lang['entries'] = '%s Eintr&auml;ge';
$lang['status'] = 'Status ';
$lang['expiry'] = 'Ablauf';
$lang['filter'] = 'Artikel-Filter';
$lang['more'] = 'Weiterlesen &hellip;';
$lang['category_label'] = 'Kategorie:';
$lang['author_label'] = 'Erstellt von:';
$lang['moretext'] = 'Text f&uuml;r den Link &bdquo;Weiterlesen &hellip;&ldquo;';
$lang['name'] = 'Name ';
$lang['news'] = 'News ';
$lang['news_return'] = 'Zur&uuml;ck';
$lang['newcategory'] = 'Neue Kategorie';
$lang['needpermission'] = 'Sie ben&ouml;tigen die Berechtigung &bdquo;%s&ldquo;, um diese Funktion nutzen zu k&ouml;nnen.';
$lang['nocategorygiven'] = 'Keine Kategorie vorhanden';
$lang['startdatetoolate'] = 'FEHLER: Der Startzeitpunkt muss VOR dem Endzeitpunkt liegen';
$lang['nocontentgiven'] = 'Kein Inhalt vorhanden';
$lang['noitemsfound'] = '<strong>Keine</strong> Eintr&auml;ge in der Kategorie %s gefunden ';
$lang['nopostdategiven'] = 'Fehler: Kein Erstellungsdatum vorhanden';
$lang['note'] = '<em>Hinweis:</em> Datum/Zeit muss im Format &bdquo;JJJJ-MM-TT hh:mm:ss&ldquo; angegeben werden.';
$lang['notitlegiven'] = 'FEHLER: Kein Titel eingegeben';
$lang['nonamegiven'] = 'FEHLER: Kein Name eingegeben';
$lang['numbertodisplay'] = 'Anzuzeigende Anzahl (ohne Eintrag werden alle Datens&auml;tze angezeigt)';
$lang['print'] = 'Drucken';
$lang['postdate'] = 'Erstellt am';
$lang['postinstall'] = 'Stellen Sie sicher, dass die Benutzer, die die News verwalten, die Berechtigung &bdquo;Modify News&ldquo; haben.';
$lang['selectcategory'] = 'Kategorie ausw&auml;hlen';
$lang['showchildcategories'] = 'Unterkategorien anzeigen';
$lang['sortascending'] = 'aufsteigend sortieren';
$lang['startdate'] = 'Startzeitpunkt';
$lang['startoffset'] = 'Beginnt mit der Anzeige ab dem <span style=&quot;font-style: italic;&quot;>n</span>-ten Eintrag';
$lang['startrequiresend'] = 'Die Eingabe eines Startzeitpunktes erfordert auch die Eingabe eines Endzeitpunktes.';
$lang['submit'] = 'Speichern';
$lang['summary'] = 'Zusammenfassung';
$lang['summarytemplate'] = 'Zusammenfassungs-Templates';
$lang['summarytemplateupdated'] = 'Das aktualisierte Zusammenfassungs-Template wurde in der Datenbank gespeichert.';
$lang['title'] = 'Titel';
$lang['options'] = 'Optionen';
$lang['optionsupdated'] = 'Die Einstellungen wurden gespeichert.';
$lang['useexpiration'] = 'Zeitsteuerung aktivieren';
$lang['eventdesc-NewsArticleAdded'] = 'Ausf&uuml;hren, wenn ein Artikel hinzugef&uuml;gt wurde.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Ausf&uuml;hren, wenn ein Artikel hinzugef&uuml;gt wurde.</p>
<h4>Parameter</h4>
<ul>
<li>&quot;news_id&quot; - ID des News-Artikels</li>
<li>&quot;category_id&quot; - ID der Kategorie f&uuml;r diesen Artikel</li>
<li>&quot;title&quot; - Titel des Artikels</li>
<li>&quot;content&quot; - Inhalt des Artikels</li>
<li>&quot;summary&quot; - Zusammenfassung des Artikels</li>
<li>&quot;status&quot; - Status des Artikels (&bdquo;Entwurf/draft&ldquo; oder &bdquo;Ver&ouml;ffentlicht/publish&ldquo;)</li>
<li>&quot;start_time&quot; - Datum, ab dem der Artikel angezeigt werden soll</li>
<li>&quot;end_time&quot; - Datum, ab dem der Artikel nicht mehr angezeigt werden soll</li>
<li>&quot;useexp&quot; - die Zeitsteuerung soll ignoriert werden oder auch nicht</li>
</ul>';
$lang['eventdesc-NewsArticleEdited'] = 'Ausf&uuml;hren, wenn ein Artikel bearbeitet wurde.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Ausf&uuml;hren, wenn ein Artikel bearbeitet wurde.</p>
<h4>Parameter</h4>
<ul>
 <li>&quot;news_id&quot; - ID des News-Artikels</li>
<li>&quot;category_id&quot; - ID der Kategorie f&uuml;r diesen Artikel</li>
<li>&quot;title&quot; - Titel des Artikels</li>
<li>&quot;content&quot; - Inhalt des Artikels</li>
<li>&quot;summary&quot; - Zusammenfassung des Artikels</li>
<li>&quot;status&quot; - Status des Artikels (&bdquo;Entwurf/draft&ldquo; oder &bdquo;Ver&ouml;ffentlicht/publish&ldquo;)</li>
<li>&quot;start_time&quot; - Datum, ab dem der Artikel angezeigt werden soll</li>
<li>&quot;end_time&quot; - Datum, ab dem der Artikel nicht mehr angezeigt werden soll</li>
<li>&quot;useexp&quot; - die Zeitsteuerung soll ignoriert werden oder auch nicht</li>
</ul>';
$lang['eventdesc-NewsArticleDeleted'] = 'Ausf&uuml;hren, wenn ein Artikel gel&ouml;scht wurde.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Ausf&uuml;hren, wenn ein Artikel gel&ouml;scht wurde.</p>
<h4>Parameter</h4>
<ul>
<li>&quot;news_id&quot; - ID des News-Artikels</li>
</ul>';
$lang['eventdesc-NewsCategoryAdded'] = 'Ausf&uuml;hren, wenn eine Kategorie hinzugef&uuml;gt wurde.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Ausf&uuml;hren, wenn eine Kategorie hinzugef&uuml;gt wurde.</p>
<h4>Parameter</h4>
<ul>
<li>&quot;category_id&quot; - ID der News-Kategorie</li>
<li>&quot;name&quot; - Name der News-Kategorie</li>
</ul>';
$lang['eventdesc-NewsCategoryEdited'] = 'Ausf&uuml;hren, wenn eine Kategorie bearbeitet wurde.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Ausf&uuml;hren, wenn eine Kategorie bearbeitet wurde.</p>
<h4>Parameter</h4>
<ul>
<li>&quot;category_id&quot; - ID der News-Kategorie</li>
<li>&quot;name&quot; - Name der News-Kategorie</li>
<li>&quot;origname&quot; - urspr&uuml;nglicher Name der News-Kategorie</li>
</ul>';
$lang['eventdesc-NewsCategoryDeleted'] = 'Ausf&uuml;hren, wenn eine Kategorie gel&ouml;scht wurde.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Ausf&uuml;hren, wenn eine Kategorie gel&ouml;scht wurde.</p>
<h4>Parameter</h4>
<ul>
<li>&quot;category_id&quot; - ID der gel&ouml;schten News-Kategorie</li>
<li>&quot;name&quot; - Name der gel&ouml;schten News-Kategorie</li>
</ul>';
$lang['help_articleid'] = 'Dieser Parameter funktioniert nur in der Detailansicht. Mit ihm kann vorgegeben werden, welcher Artikel im Detail-Modus angezeigt werden soll. Wird an dieser Stelle der Wert -1 verwendet, wird der neueste ver&ouml;ffentlichte, nicht abgelaufene Artikel angezeigt.';
$lang['helpnumber'] = 'Anzahl der maximal anzuzeigenden Eintr&auml;ge (pro Seite) &ndash; ohne Parameter werden alle Eintr&auml;ge angezeigt. Dies ist ein Synonym f&uuml;r den Parameter <tt>pagelimit</tt>.';
$lang['helpstart'] = 'Beginnt die Anzeige mit dem n-ten Eintrag &ndash; wird das Feld leer gelassen, wird mit dem ersten Eintrag begonnen.';
$lang['helpcategory'] = 'Mit diesem Parameter k&ouml;nnen Sie festlegen, aus welcher Kategorie die Eintr&auml;ge angezeigt werden. <strong>Um auch die Unterkategorien anzuzeigen, geben Sie nach dem Kategorienamen ein * ein.</strong> &Uuml;ber eine durch Kommata getrennte Liste k&ouml;nnen auch mehrere Kategorien angezeigt werden. Ohne diesen Parameter werden alle Kategorien angezeigt. Dieser Parameter funktioniert auch mit der Aktion &bdquo;fesubmit&ldquo;, obwohl dort nur eine Kategorie unterst&uuml;tzt wird.';
$lang['helpmoretext'] = 'Mit diesem Parameter wird der Text festgelegt, der nach der News-Zusammenfassung angezeigt wird, wenn der Artikel l&auml;nger als die vorgegebene L&auml;nge ist. Vorgegeben ist &bdquo;Weiterlesen &hellip;&ldquo;';
$lang['helpsummarytemplate'] = 'Verwendet ein separates Template f&uuml;r die Anzeige der Artikel-Zusammenfassungen. Dieses Template muss vorhanden sein und in der Administration des News-Moduls in der Registerkarte &bdquo;Zusammenfassungs-Template&ldquo; angezeigt werden. Ohne Parameter wird das als Standard gekennzeichnete Template verwendet.';
$lang['helpformtemplate'] = 'Verwendet ein Template f&uuml;r die Anzeige des Formulars zur &Uuml;bermittlung neuer Artikel. Dieses Template muss vorhanden sein und in der Administration des News-Moduls in der Registerkarte &bdquo;Formular-Template&ldquo; angezeigt werden. Ohne Parameter wird das als Standard gekennzeichnete Template verwendet.';
$lang['helpbrowsecattemplate'] = 'Verwendet ein Template f&uuml;r die Anzeige der Kategorien. Dieses Template muss vorhanden sein und  in der Administration des News-Moduls in der Registerkarte &bdquo;Kategorien-Template&ldquo; angezeigt werden. Sie muss jedoch nicht als Standard gekennzeichnet sein. Ohne Parameter wird das als Standard gekennzeichnete Template f&uuml;r die Anzeige verwendet.';
$lang['helpdetailtemplate'] = 'Verwendet eine separates Template f&uuml;r die Detail-Anzeige des Artikels. Dieses Template muss vorhanden sein und in der Administration des News-Moduls in der Registerkarte &bdquo;Detail-Template&ldquo; angezeigt werden. Ohne Parameter wird das als Standard gekennzeichnete Template verwendet.';
$lang['helpsortby'] = 'Felder, nach denen die Eintr&auml;ge sortiert werden. M&ouml;gliche Optionen sind: &bdquo;news_date&ldquo;, &bdquo;summary&ldquo;, &bdquo;news_data&ldquo;, &bdquo;news_category&ldquo;, &bdquo;news_title&ldquo;, &bdquo;news_extra&ldquo;, &bdquo;end_time&ldquo;, &bdquo;start_time&ldquo;, &bdquo;random&ldquo;. Standard ist &bdquo;news_date&ldquo;. Ist die gew&auml;hlte Option &bdquo;random&ldquo;, wird der Parameter &bdquo;sortasc&ldquo; ignoriert.';
$lang['helpsortasc'] = 'Sortiert Eintr&auml;ge in aufsteigender Folge anstatt in absteigender (nach Datum).';
$lang['helpdetailpage'] = 'Seite, auf der die Nachrichtendetails angezeigt werden. Das kann entweder ein Seiten-Alias oder eine Seiten-ID sein. Damit k&ouml;nnen die Nachrichtendetails in einem anderen Template als die Nachrichtenzusammenfassung angezeigt werden.';
$lang['helpshowarchive'] = 'Mit diesem Parameter werden nur die Artikel angezeigt, deren Anzeigedauer au&szlig;erhalb des aktuellen Datums liegt.';
$lang['helpbrowsecat'] = 'Mit diesem Parameter wird eine Liste der Kategorien angezeigt (browsecat=&#039;1&#039;). Kann NICHT zusammen mit dem Parameter &bdquo;category&ldquo; verwendet werden.';
$lang['helpaction'] = '&Uuml;berschreibt die vorgegebene Aktion. M&ouml;gliche Werte sind:
<ul>
<li>&quot;detail&quot; - einen bestimmten Artikel im Detail-Modus anzeigen</li>
<li>&quot;default&quot; - die Zusammenfassungansicht anzeigen</li>
<li>&quot;fesubmit&quot; - auf der Webseite ein Formular zum &Uuml;bermitteln neuer Artikel anzeigen</li>
<li>&quot;browsecat&quot; - eine Kategorienliste anzeigen.</li>
</ul>';
$lang['help'] = '<h3>Wichtiger Hinweis</h3>
<p>In der News-Modul-Version 2.9 und h&ouml;her wurde sowohl das Variablenelement <code>$entry->formatpostdate</code> als auch der Parameter &bdquo;dateformat&ldquo; entfernt. Sie sollten daher anstatt <code>$entry->formatpostdate</code> jetzt <code>$entry->postdate</code> verwenden. Das Datum kann dann mit dem Modifikator &bdquo;cms_date_format&ldquo; formatiert werden (wie in den mitgelieferten Muster-Templates gezeigt).</p>
<h3>Was macht dieses Modul?</h3>
<p>&bdquo;News&ldquo; ist ein Modul, um Artikel/Neuigkeiten Blog-&auml;hnlich auf Ihrer Seite anzuzeigen, jedoch mit mehr M&ouml;glichkeiten. Nach der Modulinstallation wird dem Men&uuml;punkt &bdquo;Inhalte&ldquo; ein Link zur Administration des News-Moduls hinzugef&uuml;gt, &uuml;ber den Sie Nachrichtenkategorien ausw&auml;hlen oder hinzuf&uuml;gen k&ouml;nnen. Wurde eine Kategorie angelegt oder ausgew&auml;hlt, wird eine Liste der vorhandenen Eintr&auml;ge dieser Kategorie angezeigt. Von hier aus k&ouml;nnen Sie dieser Kategorie Eintr&auml;ge hinzuf&uuml;gen, bearbeiten oder l&ouml;schen.</p>
<h4>Verschiedene Anzeigemethoden</h4>
<p>Aufgrund der verf&uuml;gbaren Parameter und die Unterst&uuml;tzung f&uuml;r verschiedene Templates sind die Verwendungsm&ouml;glichkeiten des Moduls extrem vielf&auml;ltig.</p>
<h4>Benutzerdefinierte Felder</h4>
<p>Im News-Modul k&ouml;nnen auch benutzerdefinierte Felder erstellt werden (einschlie&szlig;lich f&uuml;r Dateien und Bilder). Dies macht es m&ouml;glich, dass Sie den Artikeln auch PDF-Dateien oder Bilder o. &auml;. anh&auml;ngen k&ouml;nnen.</p>
<h4>Kategorien</h4>
<p>F&uuml;r die Verwaltung der Nachrichtenartikel bietet das Modul einen hierarchischen Kategorie-Mechanismus. Ein Nachrichtenartikel kann jedoch nicht mehreren Kategorien zugeordnet werden.</p>
<h4>Verfallsdatum und Status</h4>
<p>Jeder News-Artikel kann optional mit einem Verfallsdatum versehen werden, nach dem er nicht mehr auf der Webseite angezeigt werden soll. Au&szlig;erdem kann der Status des News-Artikels auf <em>&bdquo;Entwurf&ldquo;</em> gesetzt werden, um ihn dauerhaft von der Webseite zu entfernen.</p>
<h3>Sicherheit</h3>
<p>Um News-Eintr&auml;ge hinzuf&uuml;gen oder bearbeiten zu k&ouml;nnen, muss der Benutzer einer Gruppe angeh&ouml;ren, die die Berechtigung &bdquo;Modify News&ldquo; hat.</p>
<p>Um News-Eintr&auml;ge l&ouml;schen zu k&ouml;nnen, muss der Benutzer einer Gruppe angeh&ouml;ren, die die Berechtigung &bdquo;Delete News Articles&ldquo; hat.</p>
<p>Um die Templates bearbeiten zu k&ouml;nnen, muss der Benutzer einer Gruppe angeh&ouml;ren, die die Berechtigung &bdquo;Modify Templates&ldquo; hat.</p>
<p>Um die globalen News-Einstellungen zu &auml;ndern, muss der Benutzer einer Gruppe angeh&ouml;ren, die die Berechtigung &bdquo;Modify Site Preferences&ldquo; hat.</p>
<p>Um News-Eintr&auml;ge f&uuml;r die Anzeige auf der Website freizugeben, muss der Benutzer zus&auml;tzlich einer Gruppe angeh&ouml;ren, die die Berechtigung &bdquo;Approve News&ldquo; hat.</p>
<h3>Wie wird es eingesetzt?</h3>
<p>Am einfachsten kann das Modul mit dem {news}-Tag verwendet werden. Dieser f&uuml;gt die Ausgabe des Moduls in Ihr Template oder Seite ein und zeigt die News-Eintr&auml;ge an. Der einzuf&uuml;gende Code sollte so aussehen: <code>{news number=&#039;5&#039;}</code></p>
<h3>Templates</h3>
<p>Seit Version 2.3 werden die Templates des News-Moduls in der Datenbank gespeichert. Dateibasierte Templates werden nicht mehr unterst&uuml;tzt. Wenn Sie noch dateibasierte Templates verwenden, sollten Sie mit der folgenden Anleitung jedes verwendete (dateibasierte) Template importieren:</p>
<ul>
<li>Kopieren Sie den Inhalt Ihrer Template-Datei in den Zwischenspeicher Ihres Rechners.</li>
<li>Erstellen Sie eins neues Datenbank-Template <em>(je nach Bedarf f&uuml;r die Zusammenfassungs- oder Detailansicht)</em>. Geben Sie dem neuen Template den gleichen Namen wie dem alten Template (einschlie&szlig;lich der Endung .tpl). F&uuml;gen Sie den Inhalt des Zwischenspeichers ein.</li>
<li>Klicken Sie auf &bdquo;Absenden&ldquo;</li>
</ul>
<p>Mit diesem Ablauf sollte sichergestellt sein, dass Fehlermeldungen &uuml;ber Templates, die nicht gefunden werden oder &auml;hnliche Smarty-Fehler, nicht auftreten, wenn auf eine CMSms-Version aktualisiert wird, die das News-Modul 2.3 oder h&ouml;her verwendet.</p>
<h4>Template-Variablen</h4>
<ul>
	<li><strong>itemcount</strong> - maximale Anzahl der anzuzeigenden News-Artikel
	<li><strong>entry->authorname</strong> - vollst&auml;ndiger Name des News-Autors (Vor-/Nachname), wie er in der Benutzer-Verwaltung gespeichert ist</li>
</ul>
<p>Auch die Variablen der Extra-Felder k&ouml;nnen in den Templates separat verwendet werden. So l&auml;sst sich zum Beispiel das Extrafeld mit dem Namen &quot;musterfeld&quot; &uuml;ber die Variable entry->musterfeld abfragen.</p>
<p><strong>ACHTUNG:</strong> Leerzeichen m&uuml;ssen dabei durch den Unterstrich (&quot;_&quot;) ersetzt werden.</p> ';
$lang['qca'] = 'P0-617342851-1252404665837';
$lang['utma'] = '156861353.343462282.1252405474.1252405474.1252405474.1';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1252405474.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
?>